@@ -3,7 +3,7 @@ use std::pin::Pin;
 
 fn main() {
     env_logger::init();
-    futures_lite::future::block_on(async {
+    futures::executor::block_on(async {
         let mut set = IfWatcher::new().await.unwrap();
         loop {
             println!("Got event {:?}", Pin::new(&mut set).await);
